@@ -100,6 +100,7 @@ my %hierarchy = (
     'LineToPathSegment' => 'PathSegment',
     'Literals' => 'DataSource',
     'LuminanceEffect' => 'ImageTransformEffect',
+    'MarkdownExportOptions' => 'ExportOptions',
     'MasterSlide' => 'ResourceBase',
     'MasterSlides' => 'ResourceBase',
     'MatrixElement' => 'MathElement',
@@ -310,9 +311,11 @@ my %determiners = (
     'LineToPathSegment' => { 'Type' => 'LineTo', },
     'Literals' => { 'Type' => 'Literals', },
     'LuminanceEffect' => { 'Type' => 'Luminance', },
+    'MarkdownExportOptions' => { 'Format' => 'md', },
     'MasterSlide' => {  },
     'MasterSlides' => {  },
     'MathElement' => {  },
+    'MathFormat' => {  },
     'MathParagraph' => {  },
     'MatrixElement' => { 'Type' => 'Matrix', },
     'Merge' => { 'Type' => 'Merge', },
